import request from '@/utils/request'
// 查询菜单
export function listMenu() {
	return request({
		url: '/system/menu/listTwo',
		method: 'get'
	})
}

// 新增表头
export function tableHeadAdd(data) {
	return request({
		url: '/system/tableHeader',
		method: 'post',
		data
	})
}

// 查询表头
export function tableHeadList(params) {
	return request({
		url: '/system/tableHeader/list',
		method: 'get',
		params
	})
}
// 修改表头
export function tableHeadUpd(data) {
	return request({
		url: '/system/tableHeader',
		method: 'put',
		data
	})
}
// 删除表头
export function tableHeadDel(id) {
	return request({
		url: `/system/tableHeader/${id}`,
		method: 'delete'
	})
}
